##  Is the SAP LeanIX Meta Model Configurable?
Yes, the SAP LeanIX meta model is fully configurable. However, we recommend that you work with the 12 provided fact sheet types as they have been proven across industries to represent an organization's enterprise architecture best and support standardization, collaboration, and simplification - which SAP LeanIX stands for. Using the out-of-the-box meta model will help you implement best practices for lean Enterprise Architecture Management, saving you time and making internal documentation and enablement in your organization easier. Especially for organizations with lower EA maturity, it is recommended to stick to standards and best practices to streamline efforts and ensure a less disruptive EA journey. If you plan to customize your meta model, seek the support of SAP LeanIX to get guidance on how to map the meta model best to suit your organization's requirements.
To learn how to configure the meta model, see [Meta Model Configuration](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the meta model to adjust it to your requirements.").
